Installation
============
This software can be installed in multiple ways. The ways that are recommended are as follows.


Obtaining the Source
--------------------
This is a library targeted specifically to developers so you will most likely want to get your hands on the source. It can be obtained as follows.::

    $ git clone https://github.com/redvox/Eliza

Installing from PyPi
--------------------

After the release, it will be available from PyPi::

    $ pip install eliza

Installing from Source
----------------------

After cloning the source, just run::

    $ python setup.py install

